@@ -154,7 +154,7 @@ class DynamicSetting(object):
             cache_version, download_time, content = self.parse_cache_data(data=data)
             source = 'cache'
             if self.verbose:
-                print(f'{self.slug} - Loaded from cache')
+                print(f'{self.slug} - Loaded from cache and content is {"" if content is None else "not "}None')
         except (redis.connection.ConnectionError, redis.connection.TimeoutError):
             if self.verbose:
                 print(f'{self.slug} - Loading from cache failed')
