@@ -519,7 +519,7 @@ class LuaScripts(object):
         '''.format(user_ttl_with_margin=user_ttl + user_ttl_margin)
 
     @classmethod
-    def finalize_profile(cls, local):
+    def finalize_profile(cls, local=False):
         '''
         KEYS[1]: profile_key
         '''
@@ -549,7 +549,7 @@ class LuaScripts(object):
             table.insert(profile, redis.call('HGETALL', KEYS[1]))
 
             return profile                
-        '''.format(local=local)
+        '''.format(local=int(local))
 
     @classmethod
     def delete_in_cache(cls):
